# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['orthogram']

package_data = \
{'': ['*']}

install_requires = \
['python-igraph>=0.8.3,<0.9.0',
 'pyyaml>=5.3.1,<6.0.0',
 'shapely>=1.7.1,<2.0.0',
 'svgwrite>=1.4,<2.0']

setup_kwargs = {
    'name': 'orthogram',
    'version': '0.1.1',
    'description': 'Draw diagrams of graphs.',
    'long_description': '=========\nOrthogram\n=========\n\n**WARNING:** *This is work in progress.  There is no guarantee as to\nthe stability and reliability of this program.*\n\nOrthogram is a command line program and Python library that lets you\ndraw diagrams of graphs.  It reads a YAML file and produces a SVG file\nlike this one:\n\n.. image:: examples/powerplant.svg\n   :width: 100%\n\nOrthogram does not aim to be a fully-featured graph layout solution.\nActually, it offers just a single layout: grid.  More than that, you\nhave to arrange the *nodes* (i.e. graph vertices) manually in the grid\nand they stay fixed in place; the program will not attempt to move\nthem around trying to optimize any aspect of the diagram.  Styling is\nalso rather basic at the moment.  It does however try to do a decent\njob arranging the *links* (i.e. graph edges) around the nodes to\nproduce a tidy, readable drawing.\n\nWhen used as a command line tool, Orthogram reads a *diagram\ndefinition file* and produces a Scalable Vector Graphics file.  The\ndefinition file is written in YAML.\n\nInstallation\n------------\n\nYou must have Python 3.8 or newer installed in your system.  Run the\nfollowing command to install package ``orthogram`` from PyPi:\n\n.. code:: console\n\n   python -m pip install orthogram\n\nNote however that some of Orthogram\'s dependencies rely on C/C++\nlibraries that you may have to install on your system:\n\n=================  ===========\nPython Package     Library\n=================  ===========\n``python-igraph``  igraph\n``pyyaml``         LibYAML\n``shapely``        GEOS\n=================  ===========\n\nCommand line interface\n----------------------\n\nThe ``orthogram`` module is designed to be used from the command line.\nTo generate a drawing of a diagram defined in a `diagram definition\nfile`_ named ``diagram.yaml``, enter the following command:\n\n.. code:: console\n\n   python -m orthogram diagram.yaml\n\nThis will create a ``diagram.svg`` file in the same directory.  If you\nwish to create a file with a different name or in a different\ndirectory, pass the path as a second argument.\n\nThe program creates Scalable Vector Graphics (SVG) files.  Use your\nweb browser to view the drawing.  Use `Inkscape`_ to convert it to PNG\nor other supported formats.\n\n.. _Inkscape: https://inkscape.org\n\nHello world\n-----------\n\nStart the text editor of your choice and type in the following lines\nof YAML:\n\n.. code:: yaml\n\n   nodes:\n     a:\n       label: Hello\n     b:\n       label: world\n   rows:\n     - nodes: [a]\n     - nodes: ["", b]\n   links:\n     - start: a\n       end: b\n\nSave it as ``hello.yaml`` and run:\n\n.. code:: console\n\n   python -m orthogram hello.yaml\n\nThis should create a ``hello.svg`` file in the same directory.\n\nDiagram definition file\n-----------------------\n\nOrthogram uses YAML for its input file format.  Of course, YAML being\na superset of JSON, you can use JSON if you prefer so.  The top-level\nstructure must be a YAML mapping; the following keys are recognized,\neach one containing a different category of definitions:\n\n* ``diagram``\n* ``nodes``\n* ``rows``\n* ``links``\n* ``styles``\n* ``groups``\n\n``diagram``\n~~~~~~~~~~~\n\nThe ``diagram`` section contains the `attributes`_ of the diagram\nitself.  It is entirely optional; you do not need one if you do not\nintend to customize your diagram.  Here is an example of a ``diagram``\nsection:\n\n.. code:: yaml\n\n   diagram:\n     label: This is my diagram!\n     font_weight: bold\n\nThe following diagram attributes are of particular significance:\n\n``collapse_links``\n  If you set this to ``true``, collinear segments of links belonging\n  to the same ``group`` will collapse into a single segment.  This may\n  help reduce the clutter, though it depends on the application.  Try\n  it out and see.\n\n``stretch``\n  By default, the diagram resizes itself to fill the element that\n  contains it.  Set this attribute to ``false`` to make the browser\n  render the diagram in its original dimensions.\n\n``nodes``\n~~~~~~~~~\n\nThe ``nodes`` section contains mappings between node names and node\ndefinitions.  You must have at least a couple of nodes to produce a\nmeaningful diagram.  Here is an example:\n\n.. code:: yaml\n\n   nodes:\n     a:\n       label: A node\n     b:\n       label: Another node\n       stroke: blue\n\nIf you want a label with more than one line of text, use the newline\ncharacter in the string.  Even better, you can use the YAML literal\nstyle:\n\n.. code:: yaml\n\n   nodes:\n\n     single-line:\n       label: A single line label\n\n     multi-with-newlines:\n       label: Two lines separated by\\na newline character\n\n     multi-with-newlines-again:\n       label: |-\n         You can also use\n         YAML literal style\n\nNote that if the label of a node is not defined, the name of the node\nis used as a label instead.\n\n``rows``\n~~~~~~~~\n\nThe ``rows`` section of the diagram definition file is used to arrange\nthe nodes in the layout grid.  It is essential; nodes that have not\nbeen placed in the grid are not drawn at all.\n\nThe ``rows`` structure is a sequence of row definitions.  Each row\ndefinition contains a sequence of node names.  You can use an empty\nstring between the node names to leave an empty spot in the row.  Here\nis an example:\n\n.. code:: yaml\n\n   nodes:\n     a:\n     b:\n     c:\n   rows:\n     - nodes: [a]\n     - nodes: [b, "", c]\n\nNote that the ``nodes`` key is necessary.  Row definitions do not have\nany attributes, though this may change in the future.\n\n``links``\n~~~~~~~~~\n\nThe ``links`` section defines the connections between the nodes.  It\nis a sequence of link definitions. Each link must declare the names of\nthe ``start`` and ``end`` nodes, as well as any `attributes`_\nappropriate for links.  Note that the nodes must be in place before\nmaking a connection. Here is an example:\n\n.. code:: yaml\n\n   nodes:\n     a: {label: First node}\n     b: {label: Second node}\n     c: {label: Third node}\n   rows:\n     - nodes: [a,  b]\n     - nodes: ["", c]\n   links:\n     - start: a\n       end: b\n       stroke: blue\n     - start: b\n       end: c\n       stroke: "#FF8844"\n\nNote that the ``start`` and ``end`` values of a link definition can be\n*sequences* of node names as well.  This lets you make multiple\nconnections in a single definition, all links sharing the same\nattributes.  For example, the following definition creates six links:\n\n.. code:: yaml\n\n   links:\n     - start: [a, b]\n       end: [c, d, e]\n\nOf particular interest is the ``drawing_priority`` attribute.  Links\nwith a higher priority number are drawn over links with a lower\npriority.  Since the intersection of links cannot typically be avoided\nin complex diagrams, it is advised that you draw intersecting links\nwith a different ``stroke`` color to make obvious that the links are\nnot connected at the intersection points.  The ``drawing_priority``\nlets you draw sets of links as layers on top of each other, giving a\nmore consistent look to your diagram.\n\nAnother way to avoid intersecting links appearing as if the were\nconnected at the intersections is to draw a *buffer* around the links.\nAttributes ``buffer_fill`` and ``buffer_width`` control the appearance\nof the buffer.  By default, the program draws the links without a\nbuffer.\n\nLinks may have an additional ``group`` attribute, which works together\nwith the ``collapse_links`` diagram attribute.  If ``collapse_links``\nis set to true, links of the same group that run along the same axis\ncan be drawn on top of each other, thus reducing the clutter and size\nof the diagram.  The ``group`` value is just a string.  Note that\nsetting this attribute affects the drawing priority of the links.  All\nlinks in the same group must share the same priority, which is the\nhighest priority among all links in the group.\n\n``styles``\n~~~~~~~~~~\n\nYou can add style definitions to the ``styles`` section to create\nnamed styles that can be referred to by the nodes and links.  Each\nstyle definition consists of attribute key-value pairs.  For example,\nthe following two nodes are drawn in the same color:\n\n.. code:: yaml\n\n   nodes:\n     a:\n       style: reddish\n     b:\n       style: reddish\n   rows:\n     - nodes: [a, b]\n   styles:\n     reddish:\n       stroke: "#880000"\n       stroke_width: 3.0\n       fill: "#FFDDDD"\n\nAttributes defined in the element itself override the attributes\ninherited by the linked named style.\n\nThere are two special style names, ``default_node`` and\n``default_link``, which are used to set default values for all the\nnodes and links in the diagram respectively.\n\n``groups``\n~~~~~~~~~~\n\nThe ``groups`` section may be used to attach attributes to link\ngroups.  Since links in the same group may collapse on one another, it\nis usually desirable for all the links in one group to share the same\nattributes.  In the example that follows, all links are drawn in blue:\n\n.. code:: yaml\n\n   groups:\n     water:\n       stroke: blue\n       stroke_width: 4.0\n   links:\n     - start: a\n       end: b\n       group: water\n     - start: c\n       end: d\n       group: water\n\nA group definition may contain a reference to a named ``style`` if\nneeded.  Note that creating an entry in the ``groups`` section is not\nnecessary for the grouping of the links; a common ``group`` name in\neach link definition is sufficient.\n\nAttributes\n----------\n\nThe following table summarizes the attributes available to the diagram\nand its components.  Where an attribute is applicable, it shows the\ndefault value:\n\n====================  ===============  =======  =======\nAttribute             Diagram          Node     Link\n====================  ===============  =======  =======\n``arrow_aspect``                                1.5\n``arrow_back``                                  False\n``arrow_base``                                  3.0\n``arrow_forward``                               True\n``buffer_fill``                                 "none"\n``buffer_width``                                0.0\n``collapse_links``    False\n``column_margin``     24.0\n``drawing_priority``                            0\n``end_bias``                                    None\n``fill``              "none"           "none"\n``font_family``       None             None     None\n``font_size``         14.0             10.0\n``font_style``        None             None     None\n``font_weight``       None             None     None\n``group``                                       None\n``label_distance``    6.0\n``label_position``    "top"\n``label``             None             None\n``link_distance``     4.0\n``min_height``        300.0            48.0\n``min_width``         300.0            96.0\n``padding``           24.0\n``row_margin``        24.0\n``start_bias``                                  None\n``stretch``           True\n``stroke_dasharray``  None             None     None\n``stroke_width``      0.0              2.0      2.0\n``stroke``            "none"           "black"  "black"\n``text_fill``         "black"          "black"\n``text_line_height``  1.25             1.25\n====================  ===============  =======  =======\n\nThe options for the enumerated attributes are:\n\n* ``label_position``:\n\n  * ``bottom``\n  * ``top``\n\n* ``start_bias`` and ``end_bias``:\n\n  * ``horizontal``\n  * ``vertical``\n\nAPI\n---\n\nUsing the ``Diagram`` class\n~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nIf you want to create a diagram using Python, you can start by\ncreating an empty ``Diagram`` object:\n\n.. code:: python\n\n   from orthogram import Diagram, write_svg\n\n   diagram = Diagram(label="A hand-made diagram", text_fill="blue")\n\nYou can pass any diagram `attributes`_ to the constructor as key-value\npairs.\n\nYou can now add nodes to the diagram:\n\n.. code:: python\n\n   diagram.add_node("a", label="Hello")\n   diagram.add_node("b", label="Beautiful")\n   diagram.add_node("c", label="World")\n\nAgain, you can provide `attributes`_ for the node as key-value pairs.\n\nIn order to use the nodes, you must first place them in the grid:\n\n.. code:: python\n\n   diagram.add_row(["a"])\n   diagram.add_row(["b", "", "c"])\n\nThe ``add_row`` method takes a list of node names.  Note that you must\nhave added the nodes to the diagram before placing them in the grid.\nUse an empty string or None to leave an empty space between nodes.\n\nAfter placing the nodes, you can connect them via links like this:\n\n.. code:: python\n\n   diagram.add_link("a", "b", stroke="red")\n\nNote that the ``Diagram`` class offers an ``add_links`` method as\nwell, which lets you create links en masse (all having the same\nattributes).\n\nAfter you have finished building your diagram, use the ``write_svg()``\nfunction to write the SVG file:\n\n.. code:: python\n\n   write_svg(diagram, "hello.svg")\n\nUsing the ``Builder`` class\n~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nThe ``Builder`` class lets you create ``Diagram`` objects from Python\ndictionaries like the ones you load from a YAML file.  The ``add()``\nmethod imports a complete diagram definition into the builder:\n\n.. code:: python\n\n   import yaml\n   from orthogram import Builder, write_svg\n\n   builder = Builder()\n   with open("diagram.yaml") as f:\n       data = yaml.safe_load(f)\n       builder.add(data)\n   write_svg(builder.diagram, "diagram.svg")\n\nIf you have to be more specific, ``Builder`` provides the following\nmethods:\n\n=======================  ===============\nDo one                   Do many\n=======================  ===============\n``add_style()``          ``add_styles()``\n``add_group()``          ``add_groups()``\n``add_node()``           ``add_nodes()``\n``add_row()``            ``add_rows()``\n``add_link()``           ``add_links()``\n``configure_diagram()``\n=======================  ===============\n\nFor example:\n\n.. code:: python\n\n   node_def = {\n       \'label\': "Hello",\n       \'fill\': "yellow",\n       \'stroke\': "none",\n   }\n   builder.add_node(\'hello\', node_def)\n\nUse the ``help()`` Python function to read the documentation of each\nmethod.  Note that you have to do the imports in a logical order: you\nmust import the styles before using them, place the nodes before\nlinking them etc.\n\nThe ``diagram`` property of a ``Builder`` object holds the diagram\nwhich is being built.  If you want to use the ``Diagram`` API on it,\nas described in the previous section, after or while using the\nbuilder, you can certainly do so.\n\nConvenience functions\n~~~~~~~~~~~~~~~~~~~~~\n\nThe ``load_ddf()`` and ``translate()`` functions are provided as\nshortcuts:\n\n.. code:: python\n\n   from orthogram import load_ddf, translate, write_svg\n\n   # You can do this:\n   diagram = load_ddf("diagram.yaml")\n   write_svg(diagram, "diagram.svg")\n\n   # or just this:\n   translate("diagram.yaml", "diagram.svg")\n',
    'author': 'Georgios Athanasiou',
    'author_email': 'yorgath@gmail.com',
    'maintainer': 'Georgios Athanasiou',
    'maintainer_email': 'yorgath@gmail.com',
    'url': 'https://github.com/yorgath/orthogram',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
